###################################################
### chunk number 1: 
###################################################
library(glpk)


###################################################
### chunk number 2: 
###################################################
lp <- lpx_read_model("transport.mod")


###################################################
### chunk number 3: 
###################################################
numrows <- lpx_get_num_rows(lp)
numrows


for (i in 1:numrows){
	print(lpx_get_row_name(lp, i))
}


###################################################
### chunk number 4: 
###################################################

numcols <- lpx_get_num_cols(lp)
numcols

for (j in 1:numcols){
	print(lpx_get_col_name(lp, j))
}
print(lpx_get_num_nz(lp));
#for (i in 1:numrows){
#	print(lpx_get_mat_row(lp, i));
#	print(lpx_get_row_ub(lp,i));
#	print(lpx_get_row_lb(lp,i));
#}


###################################################
### chunk number 5: 
###################################################
lpx_simplex(lp)


###################################################
### chunk number 6: 
###################################################
for (i in 1:numrows){
print(lpx_get_row_name(lp, i));
print(lpx_get_row_prim(lp, i))
}


###################################################
### chunk number 7: 
###################################################
for (j in 1:numcols){
print(lpx_get_col_name(lp, j));
print(lpx_get_col_prim(lp, j))
}


###################################################
### chunk number 8: 
###################################################
print ("USING API")
canneries <- c("Seattle", "San-Diego")
capacity <- c(350, 600)
markets <- c("New-York", "Chicago", "Topeka")
demand <- c(325, 300, 275)
distance <- c(2.5, 2.5, 1.7, 1.8, 1.8, 1.4)
dim(distance) <- c(2, 3)
freight <- 90


###################################################
### chunk number 9: 
###################################################
lpi <- lpx_create_prob()
lpx_set_prob_name(lpi, "cannery API")
lpx_set_obj_name(lpi, "Total Cost")
lpx_set_obj_dir(lpi, LPX_MIN)


###################################################
### chunk number 10: 
###################################################
numlinks <- length(distance)
nummarkets <- length(markets)
numcanneries <- length(canneries)
lpx_add_cols(lpi, numlinks)
for (i in 1:numcanneries){
	cannerystartrow <- (i-1) * nummarkets
	for (j in 1:nummarkets){
		colname <-toString(c(canneries[i], markets[j]));
		transcost <- distance[i, j]*freight/1000;
		lpx_set_col_name(lpi, cannerystartrow+j, colname);
		lpx_set_col_bnds(lpi, cannerystartrow+j, LPX_LO, 0.0, 0.0);
		lpx_set_obj_coef(lpi, cannerystartrow+j, transcost)
	}
}


###################################################
### chunk number 11: 
###################################################
numcanneries <- length(canneries)
nummarkets <- length(markets)
lpx_add_rows(lpi, numcanneries+nummarkets+1)
lpx_set_row_name(lpi, 1, lpx_get_obj_name(lpi))
for (i in 1:numcanneries){
	lpx_set_row_name(lpi, i+1, toString(c("Supply", canneries[i])));
	lpx_set_row_bnds(lpi, i+1, LPX_UP, 0, capacity[i])
}
for (j in 1:nummarkets){
	lpx_set_row_name(lpi, numcanneries+j+1, toString(c("Demand", markets[j])));
	lpx_set_row_bnds(lpi, numcanneries+j+1, LPX_LO, demand[j], 0)
}


###################################################
### chunk number 12: 
###################################################
# create variables to hold the constraint information
ia <- numeric()
ja <- numeric()
ar <- numeric()

# add in objective coefficients

for (i in 1:numcols){
	ia[i] <- 1;
	ja[i] <- i;
	ar[i] <- lpx_get_obj_coef(lpi, i);
}

for (i in 1:numcanneries){
	#supply constraints
	cannerysupplyrow = numcols + (i-1)*nummarkets
	for (j in 1:nummarkets){
		ia[cannerysupplyrow+j] <- (i+1);
		ja[cannerysupplyrow+j] <- (i-1)+numcanneries *(j-1)+1;
		ar[cannerysupplyrow+j] <- 1;
	}
	#demand constraints
	marketdemandrow = numcols+numcanneries * nummarkets
	for (j in 1:nummarkets){
		colnum <- (i-1)*nummarkets+j
		ia[marketdemandrow + colnum] <- numcanneries+j+1;
		ja[marketdemandrow + colnum] <- colnum;
		ar[marketdemandrow + colnum] <- 1;
	}
}
lpx_load_matrix(lpi, length(ia), ia, ja, ar);


###################################################
### chunk number 13: 
###################################################
numrows <- lpx_get_num_rows(lpi)
numrows
numcols <- lpx_get_num_cols(lpi)
numcols
for (i in 1:numrows){
	print(lpx_get_row_name(lpi, i))
}
for (j in 1:numcols){
	print(lpx_get_col_name(lpi, j))
}
print(lpx_get_num_nz(lpi));


###################################################
### chunk number 14: 
###################################################
lpx_simplex(lpi);

for (i in 1:numrows){
print(lpx_get_row_name(lpi, i));
print(lpx_get_row_prim(lpi, i))
}
for (j in 1:numcols){
print(lpx_get_col_name(lpi, j));
print(lpx_get_col_prim(lpi, j))
}


###################################################
### chunk number 15: 
###################################################
cindex <- lpx_create_index(lp)
new_york_row = lpx_find_row(lp, "demand[New-York]") 
topeka_row = lpx_find_row(lp, "demand[Topeka]")
new_york_row
topeka_row
lpx_set_row_bnds(lp, new_york_row, LPX_LO, 300, 0)
lpx_set_row_bnds(lp, topeka_row, LPX_LO, 300, 0)


###################################################
### chunk number 16: 
###################################################
lpx_simplex(lp);

for (i in 1:numrows){
print(lpx_get_row_name(lp, i));
print(lpx_get_row_prim(lp, i));
print(lpx_get_row_dual(lp, i))
}
for (j in 1:numcols){
print(lpx_get_col_name(lp, j));
print(lpx_get_col_prim(lp, j));
print(lpx_get_obj_coef(lp, j))
}


